The super_survival is the frist function of package survival666.
You can use the function to perform batch operations on the gene expression
matrix to obtain the survival analysis of the entire transcriptome
Usage
super_survival(exp, time, status, p = 1e-04, title = "survival_rank", path)
Arguments
exp
Gene expression matrix .We need to use the count matrix here.Note
that symbol is required for the column name and sample for the row name.
time
Time data for survival analysis.You need to make sure the sample
as the row name is consistent with the gene expression matrix
status
living status of patient in survival analysis,You need to make sure the sample
as the row name is consistent with the gene expression matrix too.
p
Full in the minimum significance you can accpet here.It depend
on your need, but the number should not be too big,too broad results are meaningless.