survival_pie: Visualize the factors that influence survival analysis
Description
The checkout_survival() is the third function of survival666.
We use the function to visualize the co-expression interference of a specific
gene in survival analysis.
This is a transcriptome count matrix,Note that the matrix
requires symbol as column name and sample as row name
survivalrank
This is the result calculated by the frist function
in the survival666 package.
However,that does not prevent you from getting results that you could get
using other methods,as long as three conditions are met.
Frist,you need to calculate the p value based on the expression of a
particular phenotype and the level of gene expresion
Second,your results must be large enough,preferably for the entire
transcriptome,otherwise filtering accuracy will be reduced
Finally,you need to eliminate genes that are not significant enough,and if
you are using a regular PC,it is recommended to have no more than 2000 lines
target
target gene symbols
pcol
Digtal vector,represents the column of P value in survivalrank
symbolcol
Digtal vector,represents the column of symbol in survivalrank
path
Path to output file,do not omit '/',example:'d:/file/'.