The expression matrix was manipulated to contain less than two thousand genes.
Use the symbol as the column name and the sample number as the row name.
The reason of this is that to save space.It is best to use the complete transcriptome
as the expression matrix when using the fundtion super_survival.